@@ -1,12 +1,13 @@
 import pandas as pd
 import click
-from xpandas.module import *
+from xpandas import module
 
 
 def get_cmd():
     cmd_dict = {'c': '将csv均分为N个csv',
                 's': '每N行切分为一个csv',
-                't': '按csv中某列的值Top N行'}
+                't': '按csv中某列的值Top N行',
+                'e': '按csv中某列的值提取符合条件的行'}
     while True:
         print('Commands:')
         for i in cmd_dict.keys():
@@ -26,11 +27,13 @@ def run(csv):
     print('csv shape: [%s rows x %s columns]' % df.shape)
 
     if cmd == 's':
-        split_csv(df, csv)
+        module.split_csv(df, csv)
     elif cmd == 'c':
-        chunk_csv(df, csv)
+        module.chunk_csv(df, csv)
     elif cmd == 't':
-        top_csv(df, csv)
+        module.top_csv(df, csv)
+    elif cmd == 'e':
+        module.extract_csv(df, csv)
 
 
 if __name__ == '__main__':
